@@ -29,24 +29,14 @@
 #include "ephy-adblock-manager.h"
 #include "ephy-debug.h"
 #include "ephy-download.h"
-#include "ephy-embed-event.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
-#include "ephy-embed-single.h"
-#include "ephy-embed-utils.h"
-#include "ephy-file-helpers.h"
-#include "ephy-history-service.h"
-#include "ephy-history-types.h"
 #include "ephy-prefs.h"
-#include "ephy-request-about.h"
 #include "ephy-settings.h"
-#include "ephy-string.h"
 #include "ephy-web-view.h"
 #include "nautilus-floating-bar.h"
 
-#include <errno.h>
 #include <glib/gi18n.h>
-#include <string.h>
 #include <webkit/webkit.h>
 
 static void     ephy_embed_constructed      (GObject *object);
@@ -71,12 +61,10 @@ struct _EphyEmbedPrivate
   GtkScrolledWindow *scrolled_window;
   GtkPaned *paned;
   WebKitWebView *web_view;
-  EphyHistoryService *history_service;
   GtkWidget *inspector_window;
   GtkWidget *inspector_web_view;
   GtkWidget *inspector_scrolled_window;
   gboolean inspector_attached;
-  guint is_setting_zoom : 1;
   GSList *destroy_on_transition_list;
   GtkWidget *floating_bar;
   GtkWidget *progress;
@@ -228,50 +216,6 @@ ephy_embed_statusbar_pop (EphyEmbed *embed, guint context_id)
   ephy_embed_statusbar_update (embed, msg ? msg->text : NULL);
 }
 
-static void
-get_host_for_url_cb (gpointer service,
-                     gboolean success,
-                     gpointer result_data,
-                     gpointer user_data)
-{
-  EphyHistoryHost *host;
-  EphyEmbed *embed;
-  WebKitWebView *web_view;
-  double current_zoom;
-
-  if (success == FALSE)
-    return;
-
-  embed = EPHY_EMBED (user_data);
-  host = (EphyHistoryHost *)result_data;
-
-  web_view = embed->priv->web_view;
-
-  g_object_get (web_view,
-                "zoom-level", &current_zoom,
-                NULL);
-
-  if (host->zoom_level != current_zoom) {
-    embed->priv->is_setting_zoom = TRUE;
-    g_object_set (web_view, "zoom-level", host->zoom_level, NULL);
-    embed->priv->is_setting_zoom = FALSE;
-  }
-
-  ephy_history_host_free (host);
-}
-
-static void
-restore_zoom_level (EphyEmbed *embed,
-                    const char *address)
-{
-  /* restore zoom level */
-  if (ephy_embed_utils_address_has_web_scheme (address)) {
-    ephy_history_service_get_host_for_url (embed->priv->history_service,
-                                           address,
-                                           (EphyHistoryJobCallback)get_host_for_url_cb, embed);
-  }
-}
-
 static void
 resource_request_starting_cb (WebKitWebView *web_view,
                               WebKitWebFrame *web_frame,
@@ -315,67 +259,14 @@ remove_from_destroy_list_cb (GtkWidget *widget, EphyEmbed *embed)
 }
 
 static void
-load_status_changed_cb (WebKitWebView *view,
+load_status_changed_cb (WebKitWebView *web_view,
                         GParamSpec *spec,
                         EphyEmbed *embed)
 {
-  WebKitLoadStatus status = webkit_web_view_get_load_status (view);
-
-  if (status == WEBKIT_LOAD_COMMITTED) {
-    const gchar* uri;
-    char *history_uri;
-
-    uri = webkit_web_view_get_uri (view);
+  WebKitLoadStatus status = webkit_web_view_get_load_status (web_view);
 
+  if (status == WEBKIT_LOAD_COMMITTED)
     ephy_embed_destroy_top_widgets (embed);
-
-    restore_zoom_level (embed, uri);
-
-    if (ephy_web_view_is_loading_homepage (EPHY_WEB_VIEW (view)))
-      return;
-
-    /* TODO: move the normaliztion down to the history service? */
-    if (g_str_has_prefix (uri, EPHY_ABOUT_SCHEME))
-      history_uri = g_strdup_printf ("about:%s", uri + EPHY_ABOUT_SCHEME_LEN + 1);
-    else
-      history_uri = g_strdup (uri);
-
-    ephy_history_service_visit_url (embed->priv->history_service, history_uri);
-    g_free (history_uri);
-  }
-}
-
-static void
-zoom_changed_cb (WebKitWebView *web_view,
-                 GParamSpec *pspec,
-                 EphyEmbed  *embed)
-{
-  char *address;
-  float zoom;
-
-  g_object_get (web_view,
-                "zoom-level", &zoom,
-                NULL);
-
-  if (EPHY_EMBED (embed)->priv->is_setting_zoom) {
-    return;
-  }
-
-  address = ephy_web_view_get_location (EPHY_WEB_VIEW (web_view), TRUE);
-  if (ephy_embed_utils_address_has_web_scheme (address)) {
-    ephy_history_service_set_url_zoom_level (embed->priv->history_service,
-                                             address, zoom,
-                                             NULL, NULL);
-  }
-
-  g_free (address);
-}
-
-static void
-ephy_embed_history_cleared_cb (EphyHistoryService *history_service,
-                               EphyEmbed *embed)
-{
-  ephy_web_view_clear_history (EPHY_WEB_VIEW (embed->priv->web_view));
 }
 
 static void
@@ -451,10 +342,6 @@ ephy_embed_finalize (GObject *object)
   }
   g_slist_free (priv->destroy_on_transition_list);
 
-  g_signal_handlers_disconnect_by_func (priv->history_service,
-                                        ephy_embed_history_cleared_cb,
-                                        embed);
-
   for (list = priv->messages; list; list = list->next) {
     EphyEmbedStatusbarMsg *msg;
 
@@ -699,7 +586,7 @@ progress_update (EphyWebView *view, GParamSpec *pspec, EphyEmbed *embed)
   }
 
   uri = webkit_web_view_get_uri (priv->web_view);
-  if (!uri || strcmp (uri, "about:blank") == 0)
+  if (!uri || g_str_equal (uri, "about:blank"))
     return;
 
   progress = webkit_web_view_get_progress (priv->web_view);
@@ -776,7 +663,6 @@ ephy_embed_constructed (GObject *object)
                     "signal::notify::load-status", G_CALLBACK (load_status_changed_cb), embed,
                     "signal::resource-request-starting", G_CALLBACK (resource_request_starting_cb), embed,
                     "signal::download-requested", G_CALLBACK (download_requested_cb), embed,
-                    "signal::notify::zoom-level", G_CALLBACK (zoom_changed_cb), embed,
                     NULL);
 
   priv->status_handler_id = g_signal_connect (web_view, "notify::status-message",
@@ -825,12 +711,6 @@ ephy_embed_constructed (GObject *object)
                     NULL);
 
   ephy_embed_prefs_add_embed (embed);
-
-  priv->history_service = EPHY_HISTORY_SERVICE (ephy_embed_shell_get_global_history_service (ephy_embed_shell_get_default ()));
-
-  g_signal_connect (priv->history_service,
-                    "cleared", G_CALLBACK (ephy_embed_history_cleared_cb),
-                    embed);
 }
 
 static void
